FireblocksSdk.Api.Compliance (FireblocksSdk v0.2.1)

Copy Markdown View Source

Fireblocks Compliance API.

Covers two resource families:

  • Address Registry (/v1/address_registry) — manage workspace and per-vault opt-in/opt-out from the Fireblocks address registry.
  • Screening (/v1/screening) — read and update AML and Travel Rule screening policies, configurations, and transaction-level compliance operations.

Summary

Functions

Adds one or more vault accounts to the address registry opt-out list.

Triggers a new outgoing transaction bypassing all screening checks. Admin API users only.

Returns the address registry opt-in status for the current tenant/workspace.

Returns the address registry opt-out status for the given vault account.

Returns the AML post-screening policy for the current workspace.

Returns the AML screening configuration for the current workspace.

Returns the AML screening policy for the current workspace.

Returns legal entity information associated with the given blockchain address.

Returns legal entity information associated with the given blockchain address.

Returns full compliance details (AML + Travel Rule) for the given screened transaction.

Returns the Travel Rule post-screening policy for the current workspace.

Returns the Travel Rule screening configuration for the current workspace.

Returns the Travel Rule screening policy for the current workspace.

Returns a paginated list of vault accounts that have opted out of the address registry.

Opts the current tenant/workspace in to the Fireblocks address registry.

Opts the current tenant/workspace out of the Fireblocks address registry.

Removes the given vault account from the address registry opt-out list.

Removes all vault accounts from the address registry opt-out list.

Sets a manual AML verdict for a screened transaction.

Updates the AML screening configuration for the current workspace.

Updates global screening configuration for the current workspace.

Updates the Travel Rule screening configuration for the current workspace.

Functions

add_address_registry_vault_opt_outs(params, idempotency_key \\ "")

@spec add_address_registry_vault_opt_outs(
  keyword(),
  String.t()
) :: map()

Adds one or more vault accounts to the address registry opt-out list.

Options:

  • :vaultAccountIds (list of String.t/0) - Required. Vault account IDs to add to the opt-out list

bypass_screening_policy(tx_id, idempotency_key \\ "")

@spec bypass_screening_policy(String.t(), String.t()) :: map()

Triggers a new outgoing transaction bypassing all screening checks. Admin API users only.

  • tx_id: Fireblocks transaction ID
  • idempotency_key: Optional idempotency key

get_address_registry_tenant_status()

@spec get_address_registry_tenant_status() :: map()

Returns the address registry opt-in status for the current tenant/workspace.

get_address_registry_vault_opt_out(vault_account_id)

@spec get_address_registry_vault_opt_out(String.t()) :: map()

Returns the address registry opt-out status for the given vault account.

  • vault_account_id: The vault account ID to look up

get_aml_post_screening_policy()

@spec get_aml_post_screening_policy() :: map()

Returns the AML post-screening policy for the current workspace.

get_aml_screening_configuration()

@spec get_aml_screening_configuration() :: map()

Returns the AML screening configuration for the current workspace.

get_aml_screening_policy()

@spec get_aml_screening_policy() :: map()

Returns the AML screening policy for the current workspace.

get_screening_full_details(tx_id)

@spec get_screening_full_details(String.t()) :: map()

Returns full compliance details (AML + Travel Rule) for the given screened transaction.

  • tx_id: Fireblocks transaction ID

get_travel_rule_post_screening_policy()

@spec get_travel_rule_post_screening_policy() :: map()

Returns the Travel Rule post-screening policy for the current workspace.

get_travel_rule_screening_configuration()

@spec get_travel_rule_screening_configuration() :: map()

Returns the Travel Rule screening configuration for the current workspace.

get_travel_rule_screening_policy()

@spec get_travel_rule_screening_policy() :: map()

Returns the Travel Rule screening policy for the current workspace.

list_address_registry_vault_opt_outs(opts \\ [])

@spec list_address_registry_vault_opt_outs(keyword()) :: map()

Returns a paginated list of vault accounts that have opted out of the address registry.

Options:

  • :pageCursor (String.t/0) - Cursor for paginated results

  • :pageSize (non_neg_integer/0) - Number of results per page (1–100) The default value is 50.

  • :order - Sort order. One of "VAULT_OPT_OUT_LIST_ORDER_ASC" or "VAULT_OPT_OUT_LIST_ORDER_DESC"

opt_in_address_registry_tenant(idempotency_key \\ "")

@spec opt_in_address_registry_tenant(String.t()) :: map()

Opts the current tenant/workspace in to the Fireblocks address registry.

  • idempotency_key: Optional idempotency key

opt_out_address_registry_tenant()

@spec opt_out_address_registry_tenant() :: map()

Opts the current tenant/workspace out of the Fireblocks address registry.

remove_address_registry_vault_opt_out(vault_account_id)

@spec remove_address_registry_vault_opt_out(String.t()) :: map()

Removes the given vault account from the address registry opt-out list.

  • vault_account_id: The vault account ID to remove

remove_all_address_registry_vault_opt_outs()

@spec remove_all_address_registry_vault_opt_outs() :: map()

Removes all vault accounts from the address registry opt-out list.

set_aml_verdict(params, idempotency_key \\ "")

@spec set_aml_verdict(
  keyword(),
  String.t()
) :: map()

Sets a manual AML verdict for a screened transaction.

Options:

  • :verdict - Required. The compliance verdict. One of "ACCEPT" or "REJECT"

  • :txId (String.t/0) - Required. Fireblocks transaction ID

update_aml_screening_configuration(params, idempotency_key \\ "")

@spec update_aml_screening_configuration(
  keyword(),
  String.t()
) :: map()

Updates the AML screening configuration for the current workspace.

Options:

  • :bypassScreeningDuringServiceOutages (boolean/0) - Enable/disable bypass during service outages

  • :inboundTransactionDelay (non_neg_integer/0) - Inbound transaction delay in seconds

  • :outboundTransactionDelay (non_neg_integer/0) - Outbound transaction delay in seconds

update_screening_configuration(params, idempotency_key \\ "")

@spec update_screening_configuration(
  keyword(),
  String.t()
) :: map()

Updates global screening configuration for the current workspace.

Options:

  • :disableBypass (boolean/0) - Disable bypass screening

  • :disableUnfreeze (boolean/0) - Disable unfreeze of frozen transactions

update_travel_rule_config(params, idempotency_key \\ "")

@spec update_travel_rule_config(
  keyword(),
  String.t()
) :: map()

Updates the Travel Rule screening configuration for the current workspace.

Options:

  • :bypassScreeningDuringServiceOutages (boolean/0) - Enable/disable bypass during service outages

  • :inboundTransactionDelay (non_neg_integer/0) - Inbound transaction delay in seconds

  • :outboundTransactionDelay (non_neg_integer/0) - Outbound transaction delay in seconds