Summary
Functions
Decode a function call data, error, or event log from a deployed contract by blockchain native asset id and contract address.
Get the contract address deployed by a transaction, identified by blockchain native asset ID and transaction hash.
Return deployed contract's ABI by blockchain native asset id and contract address
Retrieve the transaction receipt by blockchain native asset ID and transaction hash
Return deployed contract's ABI by blockchain native asset id and contract address
Call a write function on a deployed contract by blockchain native asset id and contract address. This creates an onchain transaction, thus it is an async operation. It returns a transaction id that can be polled for status check
Functions
Decode a function call data, error, or event log from a deployed contract by blockchain native asset id and contract address.
Options:
:baseAssetId(String.t/0) - Required. Base assetId e.g ETH, ETH_TEST5:contractAddress(String.t/0) - Required.:dataType- Available values::error,:log,:function:data(map/0) - The data to decode, which can be a string or an object containing the data and its type.:abi(list ofmap/0) - The abi of the function/error/log to decode.
Get the contract address deployed by a transaction, identified by blockchain native asset ID and transaction hash.
base_asset_id: Base asset ID of the blockchain (e.g."ETH","ETH_TEST5")tx_hash: The transaction hash that deployed the contract
Return deployed contract's ABI by blockchain native asset id and contract address
Options:
:baseAssetId(String.t/0) - Required. Base assetId e.g ETH, ETH_TEST5:contractAddress(String.t/0) - Required.
Retrieve the transaction receipt by blockchain native asset ID and transaction hash
Options:
:baseAssetId(String.t/0) - Required. Base assetId e.g ETH, ETH_TEST5:txHash(String.t/0) - Required. Transaction hash
Return deployed contract's ABI by blockchain native asset id and contract address
Options:
:baseAssetId(String.t/0) - Required. Base assetId e.g ETH, ETH_TEST5:contractAddress(String.t/0) - Required.:abiFunction(map/0)
Call a write function on a deployed contract by blockchain native asset id and contract address. This creates an onchain transaction, thus it is an async operation. It returns a transaction id that can be polled for status check
Options:
:baseAssetId(String.t/0) - Required. Base assetId e.g ETH, ETH_TEST5:contractAddress(String.t/0) - Required.:vaultId(String.t/0) - Required. The vault account id this contract was deploy from:abiFunction(map/0):amount(String.t/0) - Amount in base asset. Being used in payable functions:feeLevel- Fee level for the write function transaction. interchangeable with the 'fee' field The default value is:medium.:fee(String.t/0) - Max fee amount for the write function transaction. interchangeable with the 'feeLevel' field:note(String.t/0) - Custom note, not sent to the blockchain, that describes the transaction at your Fireblocks workspace:useGasless(boolean/0) - The default value isfalse.:externalId(String.t/0) - External id that can be used to identify the transaction in your system. The unique identifier of the transaction outside of Fireblocks with max length of 255 characters