Summary
Functions
Creates a new API user. Admin permission is required.
Creates a new console user. Admin permission is required.
Creates a new user group.
Deletes a user group by its ID.
Returns the whitelist IP addresses for a given API user.
Returns all API users in the current tenant.
Returns audit logs for the last Day or Week.
Returns all console users in the current tenant.
Returns the current OTA (One Time Addresses) status for the workspace.
Returns a single user group by its ID.
Returns a list of all user groups in the workspace.
Returns the current workspace status (Beta).
Resets the mobile device for a console user, requiring them to re-pair.
Enables or disables OTA (One Time Address) transactions for the workspace.
Updates an existing user group's name or member list.
Functions
Creates a new API user. Admin permission is required.
Options:
:role(String.t/0) - Required.:name(String.t/0) - Required.:publicKey(String.t/0):coSignerSetupIsComplete(boolean/0)
Creates a new console user. Admin permission is required.
Options:
:role(String.t/0) - Required.:name(String.t/0) - Required.:email(String.t/0) - Required.
Creates a new user group.
Options:
:groupName(String.t/0) - The user group name:memberIds(list ofString.t/0) - Array of user IDs to include in the group
Deletes a user group by its ID.
group_id: The ID of the user group to delete.
Returns the whitelist IP addresses for a given API user.
user_id: The ID of the API user.
Returns all API users in the current tenant.
Returns audit logs for the last Day or Week.
Options:
:timePeriod- The last time period to fetch. One of:day,:week:cursor(String.t/0) - Pagination cursor - the next id to start from
Returns all console users in the current tenant.
Returns the current OTA (One Time Addresses) status for the workspace.
Returns a single user group by its ID.
group_id: The ID of the user group to retrieve.
Returns a list of all user groups in the workspace.
Returns the current workspace status (Beta).
Resets the mobile device for a console user, requiring them to re-pair.
user_id: The ID of the console user whose device will be reset.
Enables or disables OTA (One Time Address) transactions for the workspace.
enabled:trueto enable OTA transactions,falseto disable.
Updates an existing user group's name or member list.
group_id: The ID of the user group to update.
Options:
:groupName(String.t/0) - The user group name:memberIds(list ofString.t/0) - Array of user IDs to include in the group