FireblocksSdk.Api.Tokenization (FireblocksSdk v0.2.0)

Copy Markdown View Source

Summary

Functions

Facilitates the creation of a new token, supporting both EVM-based and Stellar/Ripple platforms. For EVM, it deploys the corresponding contract template to the blockchain and links the token to the workspace. For Stellar/Ripple, it links a newly created token directly to the workspace without deploying a contract. Returns the token link with status "PENDING" until the token is deployed or "SUCCESS" if no deployment is needed.

Return a linked token, with its status and metadata.

Get a deterministic address for contract deployment. The address is derived from the contract's bytecode and provided salt. This endpoint is used to get the address of a contract that will be deployed in the future.

Return a linked token, with its status and metadata.

Link an existing token to the workspace.

Return all linked tokens (paginated)

Unlink a token. The token will be unlinked from the workspace. The token will not be deleted on chain nor the refId, only the link to the workspace will be removed.

Functions

create(params, idempotentKey \\ "")

Facilitates the creation of a new token, supporting both EVM-based and Stellar/Ripple platforms. For EVM, it deploys the corresponding contract template to the blockchain and links the token to the workspace. For Stellar/Ripple, it links a newly created token directly to the workspace without deploying a contract. Returns the token link with status "PENDING" until the token is deployed or "SUCCESS" if no deployment is needed.

Options:

get(token_id)

Return a linked token, with its status and metadata.

get_deterministic_address(params, idempotentKey \\ "")

Get a deterministic address for contract deployment. The address is derived from the contract's bytecode and provided salt. This endpoint is used to get the address of a contract that will be deployed in the future.

Options:

  • :chainDescriptor (String.t/0) - Required. The base asset identifier of the blockchain (legacyId) to calculate deterministic address. Example: 'ETH'

  • :templateId (String.t/0) - Required. The template identifier (UUID). Example: 'b70701f4-d7b1-4795-a8ee-b09cdb5b850d'

  • :initParams (list of map/0) - Required. The deploy function parameters and values of the contract template. See ParameterWithValue schema.

  • :salt (String.t/0) - Required. The salt to calculate the deterministic address. Must be a number between 0 and 2^256 -1, for it to fit in the bytes32 parameter. Example: '123456789'

get_link(link_id)

Return a linked token, with its status and metadata.

link(link_req, idempotentKey \\ "")

Link an existing token to the workspace.

Options:

  • :type - Required. The type of token being link. Available values: :fungible, :non_fungible_token, :token_utility, :token_extension

  • :refId (String.t/0) - The Fireblocks' token link reference id. For example, 'BQ5R_BDESC_ABC' if it's a fungible asset

  • :displayName (String.t/0) - The token display name

  • :baseAssetId (String.t/0) - The blockchain base assetId

  • :contractAddress (String.t/0) - The contract's onchain address

list(filter)

Return all linked tokens (paginated)

Options:

unlink(link_id)

Unlink a token. The token will be unlinked from the workspace. The token will not be deleted on chain nor the refId, only the link to the workspace will be removed.