FireblocksSdk.Api.TrLink (FireblocksSdk v0.2.1)

Copy Markdown View Source

Fireblocks TRLink API.

Covers the TRSupport partner integration framework for Travel Rule compliance (/v1/screening/trlink). Manages customers (legal entities/VASPs), partner integrations, VASP discovery, asset support, and Travel Rule Message (TRM) lifecycle operations.

Summary

Functions

Assesses the Travel Rule reporting requirement for a transaction.

Connects a TRLink integration by supplying API credentials for the partner.

Creates a new TRLink customer with IVMS101-compliant identity data.

Creates a new TRLink partner integration.

Creates a Travel Rule Message with IVMS101-compliant PII.

Deletes the TRLink customer with the given customer_id.

Disconnects and removes the TRLink integration with the given integration_id.

Returns the TRLink customer with the given customer_id.

Returns a single partner integration by customer and integration IDs.

Returns all partner integrations for the given customer_id.

Returns a list of all TRLink customers.

Returns the partner's public key in JWK format for encrypting PII in Travel Rule messages.

Returns list of available TRSupport partner integrations.

Returns the complete TRSupport policy for the tenant, including pre-screening rules, post-screening rules, and missing TRM rules.

Returns a single supported asset by integration and asset IDs.

Returns a Travel Rule Message by integration and TRM IDs.

Returns a single VASP by integration and VASP IDs.

Returns a paginated list of assets supported by the given integration.

Returns a paginated list of VASPs available through the given integration.

Redirects a Travel Rule Message to a subsidiary VASP.

Associates a TRM ID with a specific destination in a multi-destination transaction.

Associates a TRM ID with a Fireblocks transaction.

Partially updates a TRLink customer's IVMS101 identity data.

Functions