FireblocksSdk.Schema (FireblocksSdk v0.2.1)

Copy Markdown View Source

Shared NimbleOptions schemas used across multiple API modules.

Only schemas that are genuinely reused by more than one module belong here. Module-specific schemas should be defined as @<function>_schema attributes directly in the module that uses them.

Summary

Functions

Schema for adding an asset to an external or internal wallet. Used by FireblocksSdk.Api.ExternalWallet and FireblocksSdk.Api.InternalWallet.

Schema for creating an external or internal wallet. Used by FireblocksSdk.Api.ExternalWallet and FireblocksSdk.Api.InternalWallet.

Schema for setting the AML/KYT customer reference ID on an external or internal wallet. Used by FireblocksSdk.Api.ExternalWallet and FireblocksSdk.Api.InternalWallet.

Functions

wallet_add_asset_request()

Schema for adding an asset to an external or internal wallet. Used by FireblocksSdk.Api.ExternalWallet and FireblocksSdk.Api.InternalWallet.

wallet_create_request()

Schema for creating an external or internal wallet. Used by FireblocksSdk.Api.ExternalWallet and FireblocksSdk.Api.InternalWallet.

wallet_set_customer_ref_id_request()

Schema for setting the AML/KYT customer reference ID on an external or internal wallet. Used by FireblocksSdk.Api.ExternalWallet and FireblocksSdk.Api.InternalWallet.