View Source FireblocksSdk.Api.Asset (FireblocksSdk v0.1.3)
Summary
Functions
Register a new asset to a workspace and return the newly created asset's details. Currently supported chains are
Set asset price for the given asset id. Returns the asset price response.
Functions
Register a new asset to a workspace and return the newly created asset's details. Currently supported chains are:
- EVM based chains
- Stellar
- Algorand
- TRON
- NEAR
- Solana
FireblocksSdk.Api.Asset.register([
blockchainId: "ETH_TEST3",
address: "0xe7A9as1oa38bc4da0248s179E30aa94CcF453991",
symbol: "TST3"
])Options:
:blockchainId(String.t/0):address(String.t/0):symbol(String.t/0)
Set asset price for the given asset id. Returns the asset price response.
FireblocksSdk.Api.Asset.register([
assetId: "ETH_TEST3",
currency: "USD",
price: 1000
])Options:
:assetId(String.t/0):currency(String.t/0):price