Embedded Wallets (NCW) API module for Fireblocks SDK.
Implements all operations under the /v1/ncw/wallets base path as defined in
the Fireblocks OpenAPI specification (tag: Embedded Wallets).
Summary
Functions
Add an asset to a specific account within a Non-Custodial Wallet.
Assign a specific Non-Custodial Wallet to a user.
Create a new account under a specific Non-Custodial Wallet.
Create a new Non-Custodial Wallet.
Get a specific account under a specific Non-Custodial Wallet.
Get addresses for a specific asset under a specific account within a Non-Custodial Wallet.
Get a specific asset under a specific account within a Non-Custodial Wallet.
Get the balance of a specific asset under a specific account within a Non-Custodial Wallet.
Get the public key of an asset associated with a specific account within a Non-Custodial Wallet, identified by its BIP44 change and address index.
Get the public key of an asset using the legacy internal path format.
Get a specific device registered to a specific Non-Custodial Wallet.
Get the key setup state of a specific device under a specific Non-Custodial Wallet.
Get wallet latest backup details, including the deviceId and backup time.
Get the public key information based on derivation path and signing algorithm within a Non-Custodial Wallet.
Retrieve all available supported assets for Non-Custodial Wallets.
Get a Non-Custodial Wallet by its ID.
Get the key setup state for a specific Non-Custodial Wallet, including required algorithms and device setup status.
Retrieve assets for a specific account under a specific Non-Custodial Wallet.
Get a paginated list of registered devices for a specific Non-Custodial Wallet.
List all Non-Custodial Wallets.
Refresh the balance of a specific asset under a specific account within a Non-Custodial Wallet.
Update the enabled/disabled status of a specific device for a Non-Custodial Wallet.
Update the enabled/disabled status of a specific Non-Custodial Wallet.
Functions
Add an asset to a specific account within a Non-Custodial Wallet.
operationId: AddEmbeddedWalletAsset
Assign a specific Non-Custodial Wallet to a user.
operationId: assignEmbeddedWallet
Create a new account under a specific Non-Custodial Wallet.
operationId: CreateEmbeddedWalletAccount
Create a new Non-Custodial Wallet.
operationId: CreateEmbeddedWallet
Get a specific account under a specific Non-Custodial Wallet.
operationId: GetEmbeddedWalletAccount
Get addresses for a specific asset under a specific account within a Non-Custodial Wallet.
operationId: GetEmbeddedWalletAddresses
Options
:pageCursor(String.t/0) - Cursor to the next page of results:pageSize(integer/0) - Number of items per page (min 1, max 100):sort- Field to sort by::addressor:createdAtThe default value is:createdAt.:order- Sort direction::ascor:descThe default value is:asc.:enabled(boolean/0) - When set, filters addresses by their enabled/disabled status
Get a specific asset under a specific account within a Non-Custodial Wallet.
operationId: GetEmbeddedWalletAsset
Get the balance of a specific asset under a specific account within a Non-Custodial Wallet.
operationId: GetEmbeddedWalletAssetBalance
@spec get_asset_public_key_info( String.t(), String.t(), String.t(), non_neg_integer(), non_neg_integer(), keyword() ) :: map()
Get the public key of an asset associated with a specific account within a Non-Custodial Wallet, identified by its BIP44 change and address index.
operationId: GetEmbeddedWalletPublicKeyInfoForAddress
Options
:compressed(boolean/0) - Whentrue, returns the public key in compressed format
@spec get_asset_public_key_info_alt( String.t(), String.t(), String.t(), non_neg_integer(), non_neg_integer(), keyword() ) :: map()
Get the public key of an asset using the legacy internal path format.
operationId: getPublicKeyInfoForAddressNcw
This endpoint is marked
x-internalin the specification. Preferget_asset_public_key_info/6for all new integrations.
Options
:compressed(boolean/0) - Whentrue, returns the public key in compressed format
Get a specific device registered to a specific Non-Custodial Wallet.
operationId: GetEmbeddedWalletDevice
Get the key setup state of a specific device under a specific Non-Custodial Wallet.
operationId: GetEmbeddedWalletDeviceSetupState
Get wallet latest backup details, including the deviceId and backup time.
operationId: GetEmbeddedWalletLatestBackup
Get the public key information based on derivation path and signing algorithm within a Non-Custodial Wallet.
operationId: getPublicKeyInfoNcw
Options
:derivationPath(String.t/0) - Required. Full BIP44 derivation path as a JSON-stringified integer array (first element must be 44):algorithm- Required. Signing algorithm:MPC_ECDSA_SECP256K1,MPC_ECDSA_SECP256R1, orMPC_EDDSA_ED25519:compressed(boolean/0) - Whentrue, returns the public key in compressed format
Retrieve all available supported assets for Non-Custodial Wallets.
operationId: GetEmbeddedWalletSupportedAssets
Options
:onlyBaseAssets(boolean/0) - Whentrue, only base assets are returned The default value istrue.:pageCursor(String.t/0) - Cursor to the next page of results:pageSize(integer/0) - Number of items per page (max 400) The default value is200.:order- Sort direction::ascor:descThe default value is:asc.
Get a Non-Custodial Wallet by its ID.
operationId: GetEmbeddedWallet
Get the key setup state for a specific Non-Custodial Wallet, including required algorithms and device setup status.
operationId: getEmbeddedWalletSetupStatus
Retrieve assets for a specific account under a specific Non-Custodial Wallet.
operationId: getEmbeddedWalletAssets
Options
:sort- Field to sort by::assetIdor:createdAtThe default value is:assetId.:pageCursor(String.t/0) - Cursor to the next page of results:pageSize(integer/0) - Number of items per page (max 400) The default value is200.:order- Sort direction::ascor:descThe default value is:asc.
Get a paginated list of registered devices for a specific Non-Custodial Wallet.
operationId: getEmbeddedWalletDevicesPaginated
Options
:sort- Field to sort by The default value is:createdAt.:pageCursor(String.t/0) - Cursor to the next page of results:pageSize(integer/0) - Number of items per page (max 400) The default value is200.:order- Sort direction::ascor:descThe default value is:asc.
List all Non-Custodial Wallets.
operationId: GetEmbeddedWallets
Options
:sort- Field to sort by The default value is:createdAt.:enabled(boolean/0) - When set, filters wallets by their enabled/disabled status:pageCursor(String.t/0) - Cursor to the next page of results:pageSize(integer/0) - Number of items per page (max 400) The default value is200.:order- Sort direction::ascor:descThe default value is:asc.
Refresh the balance of a specific asset under a specific account within a Non-Custodial Wallet.
operationId: RefreshEmbeddedWalletAssetBalance
Update the enabled/disabled status of a specific device for a Non-Custodial Wallet.
operationId: updateEmbeddedWalletDeviceStatus
Options
:enabled(boolean/0) - Required. Whether the device should be enabled (true) or disabled (false)
Update the enabled/disabled status of a specific Non-Custodial Wallet.
operationId: updateEmbeddedWalletStatus
Options
:enabled(boolean/0) - Required. Whether the wallet should be enabled (true) or disabled (false)