Shared NimbleOptions schemas used across multiple API modules.
Only schemas that are genuinely reused by more than one module belong here.
Module-specific schemas should be defined as @<function>_schema attributes
directly in the module that uses them.
Summary
Functions
Schema for adding an asset to an external or internal wallet.
Used by FireblocksSdk.Api.ExternalWallet and FireblocksSdk.Api.InternalWallet.
Schema for creating an external or internal wallet.
Used by FireblocksSdk.Api.ExternalWallet and FireblocksSdk.Api.InternalWallet.
Schema for setting the AML/KYT customer reference ID on an external or internal wallet.
Used by FireblocksSdk.Api.ExternalWallet and FireblocksSdk.Api.InternalWallet.
Functions
Schema for adding an asset to an external or internal wallet.
Used by FireblocksSdk.Api.ExternalWallet and FireblocksSdk.Api.InternalWallet.
Schema for creating an external or internal wallet.
Used by FireblocksSdk.Api.ExternalWallet and FireblocksSdk.Api.InternalWallet.
Schema for setting the AML/KYT customer reference ID on an external or internal wallet.
Used by FireblocksSdk.Api.ExternalWallet and FireblocksSdk.Api.InternalWallet.